command library
Mini-library for defining commands and command handlers.
Classes
-
ICommand<
TResult> - Implement to create a command that can be used with the Mediator.
-
ICommandHandler<
TCommand extends ICommand< TResult> , TResult> - Implement to create a handler for your custom ICommand implementation.