Implement to create a command that can be used with the Mediator.
// Create a new command, must implement ICommand<ResultType> only once.
// The command only needs fields if your handler will require them.
class ConvertToStringCommand implements ICommand<String> {
final int number;
ConvertToStringCommand(this.number);
}
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited