mediator library
Provides the architectural Mediator pattern, with CQRS support.
Mini-libraries:
commands.dart:- Use ICommand to define your commands and their result types.
- Use ICommandHandler to implement the handlers for your commands.
queries.dart:- Use IQuery to define your queries and their result types.
- Use IQueryHandler to implement the handlers for your queries.
events.dart:- Use IEvent to define your events.
Classes
- EventSubscription
- Represents a token to an event subscription, can be used to manually unsubscribe from an event.
- Mediator
- An implementation for the architectural mediator pattern, with CQRS support.