query library
Mini-library for defining queries and query handlers.
Classes
-
IQuery<
TResult> - Implement to create a query that can be used with the Mediator.
-
IQueryHandler<
TQuery extends IQuery< TResult> , TResult> - Implement to create a handler for your custom IQuery implementation.