IQuery<TResult> class abstract interface

Implement to create a query that can be used with the Mediator.

// Create a new query, must implement IQuery<ResultType> only once.
// The query only needs fields if your handler will require them.
class GetAsStringQuery implements IQuery<String> {
  final int number;
  GetAsStringQuery(this.number);
}

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited